
# comment

=pod

some POD

=cut

# simple options
-A A
-b bb

# quoted option parameters
-ccc 'ccc ccc ccc'

# quotes in quotes
-ddd "'d1 d2\" d3' d4 d5 d6"
-eee '"e1 e2\' e3" e4 e5 e6'

=pod

The following is POD and should NOT be epanded!

  -alpha beta

=cut

# simple parameters
par1 par2
par3

# cascading
@@casca

# nesting
@t/case.cfg
